@@ -6,9 +6,7 @@ import struct
 import base64
 
 class Console:
-    def __init__(self, key,
-		       host="127.0.0.1",
-                       port=5199):
+    def __init__(self, key, host="127.0.0.1", port=5199):
         """authenticator class"""
         self.console_host = host
         self.console_port = port
@@ -40,6 +38,11 @@ class Console:
         v += 1
         return v.to_bytes(4, byteorder='big') + nonce[4:]
 
+    def disconnect(self):
+        """disconnect"""
+        if self.sock is not None:
+            self.sock.close()
+        
     def connect_to(self):
         """connect to console"""
         # prepare socket
